@@ -1,4 +1,4 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Dist/Zilla/Plugin/Templates.pm
 #
@@ -17,19 +17,19 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Dist-Zilla-Plugin-Templates. If not, see <http://www.gnu.org/licenses/>.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 
 #pod =for :this This is C<Dist::Zilla::Plugin::Templates> module documentation. Read this if you are going to hack or
 #pod extend C<Dist-Zilla-Plugin-Templates>.
 #pod
-#pod =for :those If you want to convert any text file into template, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
+#pod =for :those If you want to treat source files as templates, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
 #pod topics like getting source, building, installing, bug reporting and some others are covered in the
 #pod F<README>.
 #pod
 #pod =head1 DESCRIPTION
 #pod
 #pod Implementation of the plugin is trivial. It just consumes few roles which do all the work:
-#pod C<FileFinderUser> provides a list of templates, C<TextTemplater> process them.
+#pod C<FileFinderUser> provides a list of files, C<TextTemplater> process them.
 #pod
 #pod =head1 SEE ALSO
 #pod
@@ -50,8 +50,8 @@ use Moose;
 use namespace::autoclean;
 use version 0.77;
 
-# ABSTRACT: Convert any text file into template
-our $VERSION = 'v0.6.1'; # VERSION
+# ABSTRACT: Treat source files as templates
+our $VERSION = 'v0.6.1_01'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::FileMunger';
 with 'Dist::Zilla::Role::FileFinderUser' => {
@@ -70,8 +70,8 @@ use Dist::Zilla::Plugin::Templates::File;
 #pod =method munge_files
 #pod
 #pod This is the primary method of the plugin. It is called by C<Dist::Zilla> during build. The method
-#pod iterates through the files provided by C<< $self->found_files >> (a method taken from
-#pod C<FileFinderUser> role) and process each file with C<< $self->fill_in_file >> (a method taken from
+#pod iterates through the files provided by C<< $self->found_files >> (a method defined in
+#pod C<FileFinderUser> role) and process each file with C<< $self->fill_in_file >> (a method defined in
 #pod C<TextTemplater> role). That's all, folks.
 #pod
 #pod =cut
@@ -156,22 +156,22 @@ __PACKAGE__->meta->make_immutable();
 #pod
 #pod =cut
 
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ------------------------------------------------------------------------------------------------
 #
 #   file: doc/what.pod
 #
 #   This file is part of perl-Dist-Zilla-Plugin-Templates.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ------------------------------------------------------------------------------------------------
 
 #pod =encoding UTF-8
 #pod
 #pod =head1 WHAT?
 #pod
-#pod C<Dist-Zilla-Plugin-Templates> (or just C<Templates>) is a C<Dist-Zilla> plugin allowing developers to insert
-#pod fragments of Perl code into arbitrary text files, which become I<templates>. When building a
-#pod distribution with C<Dist::Zilla>, C<Templates> plugin evaluates these fragments, and replaces each
-#pod fragment with result of its evaluation.
+#pod C<Dist-Zilla-Plugin-Templates> (or just C<Templates> for brevity) is a C<Dist-Zilla> plugin allowing developers
+#pod to insert Perl code fragments into arbitrary source text files, which become I<templates>. When
+#pod C<Dist::Zilla> builds the distribution each code fragment is evaluated and replaced with result of
+#pod evaluation.
 #pod
 #pod =cut
 
@@ -188,38 +188,39 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Templates - Convert any text file into template
+Dist::Zilla::Plugin::Templates - Treat source files as templates
 
 =head1 VERSION
 
-Version v0.6.1, released on 2015-10-31 22:59 UTC.
+Version v0.6.1_01, released on 2016-11-09 22:38 UTC.
+This is a B<trial release>.
 
 =head1 WHAT?
 
-C<Dist-Zilla-Plugin-Templates> (or just C<Templates>) is a C<Dist-Zilla> plugin allowing developers to insert
-fragments of Perl code into arbitrary text files, which become I<templates>. When building a
-distribution with C<Dist::Zilla>, C<Templates> plugin evaluates these fragments, and replaces each
-fragment with result of its evaluation.
+C<Dist-Zilla-Plugin-Templates> (or just C<Templates> for brevity) is a C<Dist-Zilla> plugin allowing developers
+to insert Perl code fragments into arbitrary source text files, which become I<templates>. When
+C<Dist::Zilla> builds the distribution each code fragment is evaluated and replaced with result of
+evaluation.
 
 This is C<Dist::Zilla::Plugin::Templates> module documentation. Read this if you are going to hack or
 extend C<Dist-Zilla-Plugin-Templates>.
 
-If you want to convert any text file into template, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
+If you want to treat source files as templates, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
 topics like getting source, building, installing, bug reporting and some others are covered in the
 F<README>.
 
 =head1 DESCRIPTION
 
 Implementation of the plugin is trivial. It just consumes few roles which do all the work:
-C<FileFinderUser> provides a list of templates, C<TextTemplater> process them.
+C<FileFinderUser> provides a list of files, C<TextTemplater> process them.
 
 =head1 OBJECT METHODS
 
 =head2 munge_files
 
 This is the primary method of the plugin. It is called by C<Dist::Zilla> during build. The method
-iterates through the files provided by C<< $self->found_files >> (a method taken from
-C<FileFinderUser> role) and process each file with C<< $self->fill_in_file >> (a method taken from
+iterates through the files provided by C<< $self->found_files >> (a method defined in
+C<FileFinderUser> role) and process each file with C<< $self->fill_in_file >> (a method defined in
 C<TextTemplater> role). That's all, folks.
 
 =head2 include
