@@ -1,4 +1,4 @@
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 #
 #   file: lib/Dist/Zilla/Plugin/Templates/File.pm
 #
@@ -17,8 +17,10 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Dist-Zilla-Plugin-Templates. If not, see <http://www.gnu.org/licenses/>.
 #
-#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#   ---------------------------------------------------------------------- copyright and license ---
 
+#pod =for test_synopsis BEGIN { die "SKIP: Not Perl code.\n" };
+#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod In a template:
@@ -27,12 +29,27 @@
 #pod     {{ include( 'verbatim.txt' )->indent; }}
 #pod     {{ include( 'template.txt' )->fill_in; }}
 #pod     {{ include( 'readme.pod' )->pod2text; }}
+#pod     {{ include( 'assa.txt' )->chomp->trim->indent; }}
+#pod     …
 #pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This is a helper module for C<Dist::Zilla::Templates>. It provides few frequently used operations
 #pod on include files.
 #pod
+#pod Usually objects are created by "include" function (see
+#pod L<Dist::Zilla::Plugin::Templates/"include">).
+#pod
+#pod The object evaluated in string context returns the file content, so
+#pod
+#pod     $file->content
+#pod
+#pod and
+#pod
+#pod     "$file"
+#pod
+#pod produces the same result.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
@@ -53,8 +70,8 @@ use namespace::autoclean 0.16;
     #   see <https://rt.cpan.org/Ticket/Display.html?id=50938>.
 use version 0.77;
 
-# ABSTRACT: TODO: Convert any text file into template
-our $VERSION = 'v0.6.1'; # VERSION
+# ABSTRACT: Frequently used operations on include files
+our $VERSION = 'v0.6.1_01'; # TRIAL VERSION
 
 extends 'Dist::Zilla::File::InMemory';
 
@@ -64,6 +81,7 @@ use overload '""' => sub {
 };
 
 use Pod::Text qw{};     # `Pod::Text` exports `pod2text` by default. Let us avoid it.
+use Carp qw{ croak };
 
 # --------------------------------------------------------------------------------------------------
 
@@ -88,7 +106,7 @@ has _plugin => (
 #pod     $file->chomp();
 #pod     $file->chomp( $count );
 #pod
-#pod Chomps file content C<$count> times. If C<$count> is not specified, the method chomps all the
+#pod Chomps the file content C<$count> times. If C<$count> is not specified, the method chomps all the
 #pod trailing newlines (more exactly: all the trailing input record separators; see core function
 #pod C<chomp> for details).
 #pod
@@ -171,12 +189,33 @@ sub indent {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method munge
+#pod
+#pod     $file->munge( \&func );
+#pod     $file->munge( sub { …modify $_ here… } );
+#pod
+#pod Calls the specified function. File content is passed to the function in C<$_> variable. Return
+#pod value of the function is ignored. Value of C<$_> variable becomes new file content. The method
+#pod returns C<$self> for chaining.
+#pod
+#pod =cut
+
+sub munge {
+    my ( $self, $sub ) = @_;
+    local $_ = $self->content;
+    $sub->();
+    $self->content( $_ );
+    return $self;
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method pod2text
 #pod
 #pod     $file->pod2text( %options );
 #pod
 #pod Converts POD to plain text. It is a simple wrapper over C<Pod::Text>. See documentation on
-#pod C<Pod::Text::new> for description of available options.
+#pod C<Pod::Text::new> for description of available options. The method returns C<$self> for chaining.
 #pod
 #pod Example:
 #pod
@@ -188,32 +227,39 @@ sub indent {
 
 sub pod2text {
     my ( $self, %opts ) = @_;
-    # Create parser object:
+    my $name = $self->name;
     my $parser = Pod::Text->new( %opts );
-    my $text;
+    my ( $text, $errata );
     $parser->output_string( \$text );
-    $parser->complain_stderr( 1 );
-    {
-        # Now do a dirty hack. `Pod::Simple` parser either print messages to `STDERR`,
-        # or creates a section at the end of the document. Let us redefine its
-        # `_complain_warn` function to catch error messages:
+    if ( $parser->can( 'errata_seen' ) ) {
+        $parser->complain_stderr( 0 );
+        $parser->parse_string_document( $self->content );
+        $errata = $parser->errata_seen;
+    } else {
+        # Now do a dirty hack. `Pod::Simple` parser prior to 3.32 either print messages to `STDERR`
+        # or creates a section at the end of the document. There is no simple way to get error
+        # messages. Let us redefine its `_complain_warn` function to catch error messages.
+        $parser->complain_stderr( 1 );
         no warnings 'redefine';                         ## no critic ( ProhibitNoWarnings )
         local *Pod::Simple::_complain_warn = sub {      ## no critic ( ProtectPrivateVars )
             my ( undef, $line, $msg ) = @_;
-            ## no critic ( RequireCarping )
-            warn sprintf( "%s at %s line %s.\n", $msg, $self->name, $line );
+            push( @{ $errata->{ $line } }, $msg );
         };
         # Ok, now parse POD and reports errors, if any:
         $parser->parse_string_document( $self->content );
-    }
+    };
     ## no critic ( RequireCarping )
     if ( $parser->any_errata_seen ) {
+        for my $line ( sort( keys( %$errata ) ) ) {
+            warn "$_ at $name line $line.\n" for @{ $errata->{ $line } };
+        };
         #   TODO: Use `log_errors_in_file` to repot POD errors?
-        die sprintf( "POD errata found at %s.\n", $self->name );
+        die "POD errata found at $name.\n";
     };
     if ( not $parser->content_seen ) {
-        die sprintf( "No POD content found at %s.\n", $self->name );
+        die "No POD content found at $name.\n";
     };
+    ## critic ( RequireCarping )
     $self->content( $text );
     return $self;
 };
@@ -224,7 +270,7 @@ sub pod2text {
 #pod
 #pod     $file->trim();
 #pod
-#pod Trims trailing whitespaces from every line.
+#pod Trims trailing whitespaces from every line. The method returns C<$self> for chaining.
 #pod
 #pod =cut
 
@@ -267,11 +313,14 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Templates::File - TODO: Convert any text file into template
+Dist::Zilla::Plugin::Templates::File - Frequently used operations on include files
 
 =head1 VERSION
 
-Version v0.6.1, released on 2015-10-31 22:59 UTC.
+Version v0.6.1_01, released on 2016-11-09 22:38 UTC.
+This is a B<trial release>.
+
+=for test_synopsis BEGIN { die "SKIP: Not Perl code.\n" };
 
 =head1 SYNOPSIS
 
@@ -281,12 +330,27 @@ In a template:
     {{ include( 'verbatim.txt' )->indent; }}
     {{ include( 'template.txt' )->fill_in; }}
     {{ include( 'readme.pod' )->pod2text; }}
+    {{ include( 'assa.txt' )->chomp->trim->indent; }}
+    …
 
 =head1 DESCRIPTION
 
 This is a helper module for C<Dist::Zilla::Templates>. It provides few frequently used operations
 on include files.
 
+Usually objects are created by "include" function (see
+L<Dist::Zilla::Plugin::Templates/"include">).
+
+The object evaluated in string context returns the file content, so
+
+    $file->content
+
+and
+
+    "$file"
+
+produces the same result.
+
 =head1 OBJECT ATTRIBUTES
 
 =head2 _plugin
@@ -302,7 +366,7 @@ C<Object>, read-only.
     $file->chomp();
     $file->chomp( $count );
 
-Chomps file content C<$count> times. If C<$count> is not specified, the method chomps all the
+Chomps the file content C<$count> times. If C<$count> is not specified, the method chomps all the
 trailing newlines (more exactly: all the trailing input record separators; see core function
 C<chomp> for details).
 
@@ -343,12 +407,21 @@ Primary purpose of the method is including a file into POD as verbatim paragraph
 
     =cut
 
+=head2 munge
+
+    $file->munge( \&func );
+    $file->munge( sub { …modify $_ here… } );
+
+Calls the specified function. File content is passed to the function in C<$_> variable. Return
+value of the function is ignored. Value of C<$_> variable becomes new file content. The method
+returns C<$self> for chaining.
+
 =head2 pod2text
 
     $file->pod2text( %options );
 
 Converts POD to plain text. It is a simple wrapper over C<Pod::Text>. See documentation on
-C<Pod::Text::new> for description of available options.
+C<Pod::Text::new> for description of available options. The method returns C<$self> for chaining.
 
 Example:
 
@@ -360,7 +433,7 @@ See L<Pod::Text/"DESCRIPTION">.
 
     $file->trim();
 
-Trims trailing whitespaces from every line.
+Trims trailing whitespaces from every line. The method returns C<$self> for chaining.
 
 =head1 SEE ALSO
 
